"""Views that run a CPU blocking operation."""

import asyncio

import aiohttp.web
import bcrypt


BCRYPT_LOG_ROUNDS = 10
PWD_TO_HASH = b'39XtQbAWcnNmqmp5'


class InBandView(aiohttp.web.View):

    async def get(self):
        bcrypt.hashpw(
            PWD_TO_HASH,
            bcrypt.gensalt(BCRYPT_LOG_ROUNDS),
        )
        return aiohttp.web.Response(
            body=(
                b"<html><head><title>In Band Blocking</title></head><body>"
                b"<h1>I ran in band!</h1></body></html>"
            )
        )


class OutBandView(aiohttp.web.View):

    async def get(self):
        loop = asyncio.get_event_loop()
        await loop.run_in_executor(
            None,
            bcrypt.hashpw,
            PWD_TO_HASH,
            bcrypt.gensalt(BCRYPT_LOG_ROUNDS),
        )
        return aiohttp.web.Response(
            body=(
                b"<html><head><title>Out Band Blocking</title></head><body>"
                b"<h1>I ran out of band!</h1></body></html>"
            )
        )
